@@ -9,6 +9,7 @@ from __future__ import absolute_import, unicode_literals
 import argparse
 import os
 
+import haas
 from .discoverer import Discoverer
 from .loader import Loader
 from .plugin_context import PluginContext
@@ -23,6 +24,8 @@ def create_argument_parser():
 
     """
     parser = argparse.ArgumentParser(prog='haas')
+    parser.add_argument('--version', action='version',
+                        version='%(prog)s {0}'.format(haas.__version__))
     verbosity = parser.add_mutually_exclusive_group()
     verbosity.add_argument('-v', '--verbose', action='store_const', default=1,
                            dest='verbosity', const=2, help='Verbose output')
@@ -37,9 +40,9 @@ def create_argument_parser():
     parser.add_argument('-b', '--buffer', action='store_true', default=False,
                         help='Buffer stdout and stderr during tests')
     parser.add_argument(
-        'start', nargs='?', default=os.getcwd(),
-        help=('Directory or dotted package/module name to start searching for '
-              'tests'))
+        'start', nargs='*', default=[os.getcwd()],
+        help=('One or more directories or dotted package/module names from '
+              'which to start searching for tests'))
     parser.add_argument('-p', '--pattern', default='test*.py',
                         help="Pattern to match tests ('test*.py' default)")
     parser.add_argument('-t', '--top-level-directory', default=None,
@@ -75,11 +78,18 @@ class HaasApplication(object):
         with PluginContext([environment_plugin]):
             loader = Loader()
             discoverer = Discoverer(loader)
-            suite = discoverer.discover(
-                start=args.start,
-                top_level_directory=args.top_level_directory,
-                pattern=args.pattern,
-            )
+            suites = [
+                discoverer.discover(
+                    start=start,
+                    top_level_directory=args.top_level_directory,
+                    pattern=args.pattern,
+                )
+                for start in args.start
+            ]
+            if len(suites) == 1:
+                suite = suites[0]
+            else:
+                suite = loader.create_suite(suites)
             test_count = suite.countTestCases()
             result_factory = lambda *args: TextTestResult(test_count, *args)
             runner = unittest.TextTestRunner(
